Document class

Document model for saving to vector database

Constructors

Document({required String id, required String filePath, required String content, required List<double> embedding, Map<String, Object?> metadata = const {}})
const

Properties

content → String
Content of the document
final
embedding → List<double>
Embedding of the document
final
filePath → String
File path of the document
final
hashCode → int
The hash code for this object.
no setterinherited
id → String
Unique identifier of the document
final
metadata → Map<String, Object?>
Metadata of the document
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited