EmbeddingChunk class

Universal model for representing a chunk with embedding

Constructors

EmbeddingChunk({required String docId, required int chunkId, required String cleanContent, required List<double> vector, Map<String, Object?> metadata = const {}})
const
EmbeddingChunk.fromJson(Map<String, Object?> json)
Creates a chunk from JSON
factory

Properties

chunkId → int
Sequential chunk number in the document (0, 1, 2, ...)
final
cleanContent → String
Cleaned content of the chunk
final
docId → String
Unique identifier of the document
final
hashCode → int
The hash code for this object.
no setterinherited
metadata → Map<String, Object?>
Metadata (source, section, lang, type, created_at and etc.)
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
vector → List<double>
Embedding vector
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Converts chunk to JSON
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited