EmbeddingProcessor class

Processor for creating embeddings from files

Constructors

EmbeddingProcessor({required String targetDirectory, required EmbeddingService embeddingService, required CliConfig config, String? outputDirectory, bool verbose = false, bool enableChunking = true, ChunkingService? chunkingService})

Properties

config → CliConfig
final
embeddingService → EmbeddingService
final
enableChunking → bool
final
hashCode → int
The hash code for this object.
no setterinherited
outputDirectory → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
targetDirectory → String
final
verbose → bool
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
processDirectory() → Future<ProcessingResult>
Process all files in the target directory
processFile(String filePath) → Future<ProcessingResult>
Process a single file
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited