TextPreprocessor class

Class for preprocessing text before vectorization

Constructors

TextPreprocessor({TextProcessingMode mode = TextProcessingMode.textual})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
mode → TextProcessingMode
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

clean(String raw) → String
Applies full text cleaning pipeline
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited